
# Flash POP
A hardware-aware efficient implementation of [Retention](https://arxiv.org/abs/2307.08621) and [POP](https://arxiv.org/abs/2402.05643) Retention - Retention augmented with a Parallel Observation Pediction (POP) mechanism.



## 🌟 Credits
- https://github.com/sustcsonglin/fla-tilelang
- https://github.com/tile-ai/tilelang
- https://github.com/leor-c/M3
- https://github.com/leor-c/REM
- https://github.com/fkodom/yet-another-retnet


